@@ -3,7 +3,8 @@
 from .datatype import *
 from junopy.utils.juno import *
 
-__methods__ = ['toJSON', 'load', 'add', 'Create', 'Update', 'Get', 'Delete', 'Deactivate', 'Reactivate', 'Cancel', 'Complete', 'SendFiles']
+__methods__ = ['toJSON', 'load', 'add', 'Create', 'Update', 'Get',
+               'Delete', 'Deactivate', 'Reactivate', 'Cancel', 'Complete', 'SendFiles']
 
 
 def EncodeValue(o, format=None):
@@ -58,9 +59,8 @@ class JunoEntity():
                     ))] if isinstance(data, list) else [self[key].type(context={'entity': self, 'key': key}, **data)] if any(data.values()) else [])
 
                 elif isinstance(data, list):
-
-                    self[key].value.extend([self[key].type(context={'entity': self, 'key': key}, **item) for item in data if any(item.values(
-                    ))])
+                    self[key].value.extend([self[key].type(item) if isinstance(item, str) or isinstance(
+                        item, int) else self[key].type(context={'entity': self, 'key': key}, **item) for item in data if not item is None])
             else:
                 data = data[0] if isinstance(data, list) else data
                 if any(data.values()):
